from channels.layers import get_channel_layer


class NotificationDispatcher:
    channel_layer = None
    room_group_name = "general"

    def __init__(self):
        self.channel_layer = get_channel_layer('default')
        if not self.channel_layer:
            raise Exception("Could not get channel layer")

    async def run_forever(self):
        # Infinite loop to continuously listen for messages
        print("Listening for messages...")
        channel_name = await self.channel_layer.new_channel()
        await self.channel_layer.group_add(self.room_group_name, channel_name)
        print("Channel name:", channel_name)
        while True:
            # Blocking receive to get the message from the channel layer
            message = await self.channel_layer.receive(channel_name)

            if (message and 'type' in message and message['type'] == 'generic.event' and 'name' in message and
                    message['name'] == 'user_notification'):
                if 'message' in message and 'event_id' in message:
                    print("Received message:", message['message'], "with event_id:", message['event_id'])
                    await self.dispatch(message['message'], message['event_id'])

    async def dispatch(self, message, event_id):
        print("Dispatching message:", message, "with event_id:", event_id)
